@@ -10,6 +10,7 @@ import pkgutil
 import re
 import sys
 import tempfile
+import traceback
 from contextlib import contextmanager
 from dataclasses import dataclass, field
 from enum import Enum
@@ -33,7 +34,12 @@ from typing import (
 )
 
 from robotcode.core.lsp.types import Position, Range
-from robotcode.language_server.robotframework.utils.ast_utils import (
+from robotcode.language_server.robotframework.utils.markdownformatter import (
+    MarkDownFormatter,
+)
+from robotcode.robot.utils import get_robot_version
+
+from ..utils.ast_utils import (
     HasError,
     HasErrors,
     Token,
@@ -41,12 +47,7 @@ from robotcode.language_server.robotframework.utils.ast_utils import (
     range_from_token,
     strip_variable_token,
 )
-from robotcode.language_server.robotframework.utils.markdownformatter import (
-    MarkDownFormatter,
-)
-from robotcode.language_server.robotframework.utils.match import normalize, normalize_namespace
-from robotcode.language_server.robotframework.utils.version import get_robot_version
-
+from ..utils.match import normalize, normalize_namespace
 from .entities import (
     ArgumentDefinition,
     ImportedVariableDefinition,
@@ -93,7 +94,12 @@ ALL_RUN_KEYWORDS = [
 
 BUILTIN_LIBRARY_NAME = "BuiltIn"
 RESERVED_LIBRARY_NAME = "Reserved"
-DEFAULT_LIBRARIES = (BUILTIN_LIBRARY_NAME, RESERVED_LIBRARY_NAME, "Easter")
+
+if get_robot_version() < (7, 0):
+    DEFAULT_LIBRARIES = {BUILTIN_LIBRARY_NAME, RESERVED_LIBRARY_NAME, "Easter"}
+else:
+    DEFAULT_LIBRARIES = {BUILTIN_LIBRARY_NAME, "Easter"}
+
 ROBOT_LIBRARY_PACKAGE = "robot.libraries"
 
 ALLOWED_LIBRARY_FILE_EXTENSIONS = [".py"]
@@ -309,12 +315,20 @@ class TypeDoc:
         return result
 
 
+@dataclass
+class SourceAndLineInfo:
+    source: str
+    line_no: int
+
+
 @dataclass
 class Error:
     message: str
     type_name: str
     source: Optional[str] = None
     line_no: Optional[int] = None
+    message_traceback: Optional[List[SourceAndLineInfo]] = None
+    traceback: Optional[List[SourceAndLineInfo]] = None
 
 
 class KeywordArgumentKind(Enum):
@@ -330,9 +344,14 @@ class KeywordArgumentKind(Enum):
 def robot_arg_repr(arg: Any) -> Optional[str]:
     from robot.running.arguments.argumentspec import ArgInfo
 
+    if get_robot_version() >= (7, 0):
+        from robot.utils import NOT_SET as robot_notset  # noqa: N811
+    else:
+        robot_notset = ArgInfo.NOTSET
+
     robot_arg = cast(ArgInfo, arg)
 
-    if robot_arg.default is ArgInfo.NOTSET:
+    if robot_arg.default is robot_notset:
         return None
 
     if robot_arg.default is None:
@@ -369,7 +388,11 @@ class ArgumentInfo:
             name=robot_arg.name,
             default_value=robot_arg_repr(robot_arg),
             str_repr=str(arg),
-            types=robot_arg.types_reprs,
+            types=robot_arg.types_reprs
+            if get_robot_version() < (7, 0)
+            else [str(robot_arg.type)]
+            if robot_arg.type
+            else None,
             kind=KeywordArgumentKind[robot_arg.kind],
             required=robot_arg.required,
         )
@@ -418,6 +441,7 @@ class ArgumentSpec:
     var_positional: Any
     named_only: Any
     var_named: Any
+    embedded: Any
     defaults: Any
     types: Any
 
@@ -431,6 +455,7 @@ class ArgumentSpec:
             var_positional=spec.var_positional,
             named_only=spec.named_only,
             var_named=spec.var_named,
+            embedded=spec.embedded if get_robot_version() >= (7, 0) else None,
             defaults={k: str(v) for k, v in spec.defaults.items()} if spec.defaults else {},
             types=None,
         )
@@ -455,17 +480,31 @@ class ArgumentSpec:
         )
 
         if not hasattr(self, "__robot_arguments"):
-            self.__robot_arguments = RobotArgumentSpec(
-                self.name,
-                self.type,
-                self.positional_only,
-                self.positional_or_named,
-                self.var_positional,
-                self.named_only,
-                self.var_named,
-                self.defaults,
-                self.types,
-            )
+            if get_robot_version() < (7, 0):
+                self.__robot_arguments = RobotArgumentSpec(
+                    self.name,
+                    self.type,
+                    self.positional_only,
+                    self.positional_or_named,
+                    self.var_positional,
+                    self.named_only,
+                    self.var_named,
+                    self.defaults,
+                    self.types,
+                )
+            else:
+                self.__robot_arguments = RobotArgumentSpec(
+                    self.name,
+                    self.type,
+                    self.positional_only,
+                    self.positional_or_named,
+                    self.var_positional,
+                    self.named_only,
+                    self.var_named,
+                    self.embedded,
+                    self.defaults,
+                    self.types,
+                )
         self.__robot_arguments.name = self.name
         if validate:
             resolver = ArgumentResolver(
@@ -481,7 +520,12 @@ class ArgumentSpec:
                 pass
 
         positional, named = MyNamedArgumentResolver(self.__robot_arguments).resolve(arguments, variables)
-        positional, named = VariableReplacer(resolve_variables_until).replace(positional, named, variables)
+        if get_robot_version() < (7, 0):
+            positional, named = VariableReplacer(resolve_variables_until).replace(positional, named, variables)
+        else:
+            positional, named = VariableReplacer(self.__robot_arguments, resolve_variables_until).replace(
+                positional, named, variables
+            )
         positional, named = DictToKwargs(self.__robot_arguments, dict_to_kwargs).handle(positional, named)
         return positional, named
 
@@ -710,7 +754,10 @@ class KeywordDoc(SourceEntity):
         )
 
     def is_reserved(self) -> bool:
-        return self.libname == RESERVED_LIBRARY_NAME
+        if get_robot_version() < (7, 0):
+            return self.libname == RESERVED_LIBRARY_NAME
+
+        return False
 
     def is_any_run_keyword(self) -> bool:
         return self.libname == BUILTIN_LIBRARY_NAME and self.name in ALL_RUN_KEYWORDS
@@ -1261,14 +1308,9 @@ class KeywordWrapper:
         return None
 
 
-class Traceback(NamedTuple):
-    source: str
-    line_no: int
-
-
 class MessageAndTraceback(NamedTuple):
     message: str
-    traceback: List[Traceback]
+    traceback: List[SourceAndLineInfo]
 
 
 __RE_MESSAGE = re.compile(r"^Traceback.*$", re.MULTILINE)
@@ -1280,7 +1322,7 @@ def get_message_and_traceback_from_exception_text(text: str) -> MessageAndTraceb
 
     return MessageAndTraceback(
         message=splitted[0].strip(),
-        traceback=[Traceback(t.group(1), int(t.group(2))) for t in __RE_TRACEBACK.finditer(splitted[1])]
+        traceback=[SourceAndLineInfo(t.group(1), int(t.group(2))) for t in __RE_TRACEBACK.finditer(splitted[1])]
         if len(splitted) > 1
         else [],
     )
@@ -1295,13 +1337,19 @@ def error_from_exception(ex: BaseException, default_source: Optional[str], defau
             type_name=type(ex).__qualname__,
             source=tr.source,
             line_no=tr.line_no,
+            message_traceback=message_and_traceback.traceback,
         )
 
+    exc_type, exc_value, tb_type = sys.exc_info()
+    txt = "".join(traceback.format_exception(exc_type, exc_value, tb_type))
+    message_and_traceback = get_message_and_traceback_from_exception_text(txt)
+
     return Error(
         message=str(ex),
         type_name=type(ex).__qualname__,
         source=default_source,
         line_no=default_line_no,
+        traceback=message_and_traceback.traceback if message_and_traceback else None,
     )
 
 
@@ -1312,6 +1360,7 @@ class _Variable(object):
     source: Optional[str] = None
     lineno: Optional[int] = None
     error: Optional[str] = None
+    separator: Optional[str] = None
 
     def report_invalid_syntax(self, message: str, level: str = "ERROR") -> None:
         pass
@@ -1387,7 +1436,10 @@ def resolve_robot_variables(
 
     if variables is not None:
         vars = [_Variable(k, v) for k, v in variables.items() if v is not None and not isinstance(v, NativeValue)]
-        result.set_from_variable_table(vars)
+        if get_robot_version() < (7, 0):
+            result.set_from_variable_table(vars)
+        else:
+            result.set_from_variable_section(vars)
 
         for k2, v2 in variables.items():
             if isinstance(v2, NativeValue):
@@ -1454,7 +1506,7 @@ def _find_library_internal(
     robot_variables = resolve_robot_variables(working_dir, base_dir, command_line_variables, variables)
 
     try:
-        name = robot_variables.replace_string(name.replace("\\", "\\\\"), ignore_errors=False)
+        name = robot_variables.replace_string(name, ignore_errors=False)
     except DataError as error:
         raise DataError(f"Replacing variables from setting 'Library' failed: {error}")
 
@@ -1518,6 +1570,7 @@ def get_library_doc(
 ) -> LibraryDoc:
     import robot.running.testlibraries
     from robot.libdocpkg.robotbuilder import KeywordDocBuilder
+    from robot.libraries import STDLIBS
     from robot.output import LOGGER
     from robot.output.loggerhelper import AbstractLogger
     from robot.running.outputcapture import OutputCapturer
@@ -1604,7 +1657,14 @@ def get_library_doc(
                 python_path=sys.path,
             )
 
-        library_name = name
+        if name in STDLIBS and import_name.startswith(ROBOT_LIBRARY_PACKAGE + "."):
+            library_name = name
+        else:
+            if import_name.startswith(ROBOT_LIBRARY_PACKAGE + "."):
+                library_name = import_name[len(ROBOT_LIBRARY_PACKAGE + ".") :]
+            else:
+                library_name = import_name
+
         library_name_path = Path(import_name)
         if library_name_path.exists():
             library_name = library_name_path.stem
@@ -1751,7 +1811,7 @@ def get_library_doc(
                     from robot.libdocpkg.datatypes import TypeDoc as RobotTypeDoc
                     from robot.running.arguments.argumentspec import TypeInfo
 
-                    def _yield_type_info(info: TypeInfo) -> TypeInfo:
+                    def _yield_type_info(info: TypeInfo) -> Iterable[TypeInfo]:
                         if not info.is_union:
                             yield info
                         for nested in info.nested:
@@ -1763,10 +1823,11 @@ def get_library_doc(
                             for arg in kw.args:
                                 kw.type_docs[arg.name] = {}
                                 for type_info in _yield_type_info(arg.type):
-                                    type_doc = RobotTypeDoc.for_type(type_info.type, custom_converters)
-                                    if type_doc:
-                                        kw.type_docs[arg.name][type_info.name] = type_doc.name
-                                        type_docs.setdefault(type_doc, set()).add(kw.name)
+                                    if type_info.type is not None:
+                                        type_doc = RobotTypeDoc.for_type(type_info.type, custom_converters)
+                                        if type_doc:
+                                            kw.type_docs[arg.name][type_info.name] = type_doc.name
+                                            type_docs.setdefault(type_doc, set()).add(kw.name)
                         for type_doc, usages in type_docs.items():
                             type_doc.usages = sorted(usages, key=str.lower)
                         return set(type_docs)
@@ -1821,7 +1882,7 @@ def _find_variables_internal(
     robot_variables = resolve_robot_variables(working_dir, base_dir, command_line_variables, variables)
 
     try:
-        name = robot_variables.replace_string(name.replace("\\", "\\\\"), ignore_errors=False)
+        name = robot_variables.replace_string(name, ignore_errors=False)
     except DataError as error:
         raise DataError(f"Replacing variables from setting 'Variables' failed: {error}")
 
@@ -1925,7 +1986,7 @@ def get_variables_doc(
                         return self._get_variables(self.var_file, args)
 
                     def is_dynamic(self) -> bool:
-                        return bool(self._is_dynamic(self.var_file))
+                        return hasattr(self.var_file, "get_variables") or hasattr(self.var_file, "getVariables")
 
                 module_importer = Importer("variable file", LOGGER)
 
@@ -2026,13 +2087,13 @@ def get_variables_doc(
                 # TODO: add type information of the value including dict key names and member names
                 libdoc.variables = [
                     ImportedVariableDefinition(
-                        1,
-                        0,
-                        1,
-                        0,
-                        source or (module_spec.origin if module_spec is not None else None) or "",
-                        name,
-                        None,
+                        line_no=1,
+                        col_offset=0,
+                        end_line_no=1,
+                        end_col_offset=0,
+                        source=source or (module_spec.origin if module_spec is not None else None) or "",
+                        name=name if get_robot_version() < (7, 0) else f"${{{name}}}",
+                        name_token=None,
                         value=NativeValue(value)
                         if value is None or isinstance(value, (int, float, bool, str))
                         else None,
@@ -2094,7 +2155,7 @@ def find_file(
 
     robot_variables = resolve_robot_variables(working_dir, base_dir, command_line_variables, variables)
     try:
-        name = robot_variables.replace_string(name.replace("\\", "\\\\"), ignore_errors=False)
+        name = robot_variables.replace_string(name, ignore_errors=False)
     except DataError as error:
         raise DataError(f"Replacing variables from setting '{file_type}' failed: {error}")
 
@@ -2118,7 +2179,11 @@ class CompleteResult(NamedTuple):
 
 
 def is_file_like(name: Optional[str]) -> bool:
-    return name is not None and (name.startswith((".", "/", os.sep)) or "/" in name or os.sep in name)
+    if name is None:
+        return False
+
+    base, filename = os.path.split(name)
+    return name.startswith(".") or bool(base) and filename != name
 
 
 def iter_module_names(name: Optional[str] = None) -> Iterator[str]:
@@ -2143,15 +2208,12 @@ def iter_module_names(name: Optional[str] = None) -> Iterator[str]:
             yield e.name
 
 
-NOT_WANTED_FILE_EXTENSIONS = [".dist-info"]
+NOT_WANTED_DIR_EXTENSIONS = [".dist-info"]
 
 
 def iter_modules_from_python_path(
     path: Optional[str] = None,
 ) -> Iterator[CompleteResult]:
-    allow_modules = True if not path or not ("/" in path or os.sep in path) else False
-    allow_files = True if not path or "/" in path or os.sep in path else False
-
     path = path.replace(".", os.sep) if path is not None and not path.startswith((".", "/", os.sep)) else path
 
     if path is None:
@@ -2166,16 +2228,13 @@ def iter_modules_from_python_path(
                     f.is_file()
                     and f.suffix in ALLOWED_LIBRARY_FILE_EXTENSIONS
                     or f.is_dir()
-                    and f.suffix not in NOT_WANTED_FILE_EXTENSIONS
+                    and f.suffix not in NOT_WANTED_DIR_EXTENSIONS
                 ):
                     if f.is_dir():
                         yield CompleteResult(f.name, CompleteResultKind.MODULE)
 
                     if f.is_file():
-                        if allow_modules:
-                            yield CompleteResult(f.stem, CompleteResultKind.MODULE)
-                        if allow_files:
-                            yield CompleteResult(f.name, CompleteResultKind.FILE)
+                        yield CompleteResult(f.stem, CompleteResultKind.MODULE)
 
 
 def complete_library_import(
@@ -2184,7 +2243,7 @@ def complete_library_import(
     base_dir: str = ".",
     command_line_variables: Optional[Dict[str, Optional[Any]]] = None,
     variables: Optional[Dict[str, Optional[Any]]] = None,
-) -> Optional[List[CompleteResult]]:
+) -> List[CompleteResult]:
     _update_env(working_dir)
 
     result: List[CompleteResult] = []
@@ -2199,31 +2258,42 @@ def complete_library_import(
     if name is not None:
         robot_variables = resolve_robot_variables(working_dir, base_dir, command_line_variables, variables)
 
-        name = robot_variables.replace_string(name.replace("\\", "\\\\"), ignore_errors=True)
+        name = robot_variables.replace_string(name, ignore_errors=True)
 
-    if name is None or not name.startswith((".", "/", os.sep)):
+    file_like = is_file_like(name)
+
+    if name is None or not file_like:
         result += list(iter_modules_from_python_path(name))
 
-    if name is None or (is_file_like(name) and (name.endswith(("/", os.sep)))):
+    if name is None or file_like:
         name_path = Path(name if name else base_dir)
-        if name_path.is_absolute():
-            path = name_path
+        if name and name_path.is_absolute():
+            paths = [name_path]
         else:
-            path = Path(base_dir, name) if name else Path(base_dir)
-
-        path = path.resolve()
-
-        if path.exists() and path.is_dir():
-            result += [
-                CompleteResult(
-                    str(f.name),
-                    CompleteResultKind.FILE if f.is_file() else CompleteResultKind.FOLDER,
-                )
-                for f in path.iterdir()
-                if not f.name.startswith(("_", "."))
-                and (f.is_dir() or (f.is_file() and f.suffix in ALLOWED_LIBRARY_FILE_EXTENSIONS))
+            paths = [
+                Path(base_dir, name) if name else Path(base_dir),
+                *((Path(s) for s in sys.path) if not name else []),
+                *((Path(s, name) for s in sys.path) if name and not name.startswith(".") else []),
             ]
 
+        for p in paths:
+            path = p.resolve()
+
+            if path.exists() and path.is_dir():
+                result += [
+                    CompleteResult(
+                        str(f.name),
+                        CompleteResultKind.FILE if f.is_file() else CompleteResultKind.FOLDER,
+                    )
+                    for f in path.iterdir()
+                    if not f.name.startswith(("_", "."))
+                    and (
+                        (f.is_file() and f.suffix in ALLOWED_LIBRARY_FILE_EXTENSIONS)
+                        or f.is_dir()
+                        and f.suffix not in NOT_WANTED_DIR_EXTENSIONS
+                    )
+                ]
+
     return list(set(result))
 
 
@@ -2242,7 +2312,7 @@ def iter_resources_from_python_path(
                     f.is_file()
                     and f.suffix in ALLOWED_RESOURCE_FILE_EXTENSIONS
                     or f.is_dir()
-                    and f.suffix not in NOT_WANTED_FILE_EXTENSIONS
+                    and f.suffix not in NOT_WANTED_DIR_EXTENSIONS
                 ):
                     yield CompleteResult(
                         f.name,
@@ -2264,7 +2334,7 @@ def complete_resource_import(
     if name is not None:
         robot_variables = resolve_robot_variables(working_dir, base_dir, command_line_variables, variables)
 
-        name = robot_variables.replace_string(name.replace("\\", "\\\\"), ignore_errors=True)
+        name = robot_variables.replace_string(name, ignore_errors=True)
 
     if name is None or not name.startswith(".") and not name.startswith("/") and not name.startswith(os.sep):
         result += list(iter_resources_from_python_path(name))
@@ -2290,62 +2360,6 @@ def complete_resource_import(
     return list(set(result))
 
 
-def iter_variables_from_python_path(
-    path: Optional[str] = None,
-) -> Iterator[CompleteResult]:
-    if get_robot_version() >= (5, 0):
-        allow_modules = True if not path or not ("/" in path or os.sep in path) else False
-        allow_files = True if not path or "/" in path or os.sep in path else False
-
-        path = path.replace(".", os.sep) if path is not None and not path.startswith((".", "/", os.sep)) else path
-
-        if path is None:
-            paths = sys.path
-        else:
-            paths = [str(Path(s, path)) for s in sys.path]
-
-        for e in [Path(p) for p in set(paths)]:
-            if e.is_dir():
-                for f in e.iterdir():
-                    if not f.name.startswith(("_", ".")) and (
-                        f.is_file()
-                        and f.suffix in ALLOWED_VARIABLES_FILE_EXTENSIONS
-                        or f.is_dir()
-                        and f.suffix not in NOT_WANTED_FILE_EXTENSIONS
-                    ):
-                        if f.is_dir():
-                            yield CompleteResult(f.name, CompleteResultKind.MODULE)
-
-                        if f.is_file():
-                            if allow_modules and f.suffix.lower() not in [
-                                ".yaml",
-                                ".yml",
-                                *[".json" if get_robot_version() >= (6, 1) else []],
-                            ]:
-                                yield CompleteResult(f.stem, CompleteResultKind.VARIABLES_MODULE)
-                            if allow_files:
-                                yield CompleteResult(f.name, CompleteResultKind.VARIABLES)
-    else:
-        if path is None:
-            paths = sys.path
-        else:
-            paths = [str(Path(s, path)) for s in sys.path]
-
-        for e in [Path(p) for p in set(paths)]:
-            if e.is_dir():
-                for f in e.iterdir():
-                    if not f.name.startswith(("_", ".")) and (
-                        f.is_file()
-                        and f.suffix in ALLOWED_VARIABLES_FILE_EXTENSIONS
-                        or f.is_dir()
-                        and f.suffix not in NOT_WANTED_FILE_EXTENSIONS
-                    ):
-                        yield CompleteResult(
-                            f.name,
-                            CompleteResultKind.VARIABLES if f.is_file() else CompleteResultKind.FOLDER,
-                        )
-
-
 def complete_variables_import(
     name: Optional[str],
     working_dir: str = ".",
@@ -2360,29 +2374,42 @@ def complete_variables_import(
     if name is not None:
         robot_variables = resolve_robot_variables(working_dir, base_dir, command_line_variables, variables)
 
-        name = robot_variables.replace_string(name.replace("\\", "\\\\"), ignore_errors=True)
+        name = robot_variables.replace_string(name, ignore_errors=True)
 
-    if name is None or not name.startswith(".") and not name.startswith("/") and not name.startswith(os.sep):
-        result += list(iter_variables_from_python_path(name))
+    file_like = get_robot_version() < (5, 0) or is_file_like(name)
 
-    if name is None or name.startswith((".", "/", os.sep)):
+    if get_robot_version() >= (5, 0) and (name is None or not file_like):
+        result += list(iter_modules_from_python_path(name))
+
+    if name is None or file_like:
         name_path = Path(name if name else base_dir)
-        if name_path.is_absolute():
-            path = name_path.resolve()
+        if name and name_path.is_absolute():
+            paths = [name_path]
         else:
-            path = Path(base_dir, name if name else base_dir).resolve()
-
-        if path.exists() and (path.is_dir()):
-            result += [
-                CompleteResult(
-                    str(f.name),
-                    CompleteResultKind.VARIABLES if f.is_file() else CompleteResultKind.FOLDER,
-                )
-                for f in path.iterdir()
-                if not f.name.startswith(("_", "."))
-                and (f.is_dir() or (f.is_file() and f.suffix in ALLOWED_VARIABLES_FILE_EXTENSIONS))
+            paths = [
+                Path(base_dir, name) if name else Path(base_dir),
+                *((Path(s) for s in sys.path) if not name else []),
+                *((Path(s, name) for s in sys.path) if name and not name.startswith(".") else []),
             ]
 
+        for p in paths:
+            path = p.resolve()
+
+            if path.exists() and path.is_dir():
+                result += [
+                    CompleteResult(
+                        str(f.name),
+                        CompleteResultKind.FILE if f.is_file() else CompleteResultKind.FOLDER,
+                    )
+                    for f in path.iterdir()
+                    if not f.name.startswith(("_", "."))
+                    and (
+                        (f.is_file() and f.suffix in ALLOWED_VARIABLES_FILE_EXTENSIONS)
+                        or f.is_dir()
+                        and f.suffix not in NOT_WANTED_DIR_EXTENSIONS
+                    )
+                ]
+
     return list(set(result))
 
 
