@@ -39,6 +39,7 @@ from robotcode.core.lsp.types import (
     Range,
     TextEdit,
 )
+from robotcode.robot.utils import get_robot_version
 
 from ...common.decorators import language_id, trigger_characters
 from ...common.text_document import TextDocument
@@ -57,7 +58,6 @@ from ..utils.ast_utils import (
     whitespace_at_begin_of_token,
     whitespace_from_begin_of_token,
 )
-from ..utils.version import get_robot_version
 from .protocol_part import RobotLanguageServerProtocolPart
 
 if TYPE_CHECKING:
@@ -646,31 +646,53 @@ class CompletionCollector(ModelHelperMixin):
         ]
 
     def get_keyword_snipped_text(self, kw: KeywordDoc, in_template: bool) -> str:
-        from robot.variables.search import VariableIterator
+        result = ""
+        after: Optional[str] = None
 
         if not kw.is_embedded:
             return kw.name
 
-        result = ""
-        after: Optional[str] = None
-        for index, (before, variable, after) in enumerate(
-            VariableIterator(kw.name, identifiers="$", ignore_errors=True)
-        ):
-            var_name = variable[2:-1].split(":", 1)[0]
-            result += before
-            result += "${" + str(index + 1) + ":"
-            if in_template:
-                result += "\\${"
+        if get_robot_version() < (7, 0):
+            from robot.variables.search import VariableIterator
 
-            result += var_name
+            for index, (before, variable, after) in enumerate(
+                VariableIterator(kw.name, identifiers="$", ignore_errors=True)
+            ):
+                var_name = variable[2:-1].split(":", 1)[0]
+                result += before
+                result += "${" + str(index + 1) + ":"
+                if in_template:
+                    result += "\\${"
 
-            if in_template:
-                result += "\\}"
+                result += var_name
 
-            result += "}"
+                if in_template:
+                    result += "\\}"
 
-        if after:
-            result += after
+                result += "}"
+
+            if after:
+                result += after
+
+        else:
+            from robot.variables.search import VariableMatches
+
+            for index, match in enumerate(VariableMatches(kw.name, identifiers="$", ignore_errors=True)):
+                var_name = variable[2:-1].split(":", 1)[0]
+                result += match.before
+                result += "${" + str(index + 1) + ":"
+                if in_template:
+                    result += "\\${"
+
+                result += var_name
+
+                if in_template:
+                    result += "\\}"
+
+                result += "}"
+
+            if after:
+                result += match.after
 
         return result
 
@@ -1520,16 +1542,36 @@ class CompletionCollector(ModelHelperMixin):
             if text_before_position != "" and all(c == "." for c in text_before_position):
                 return None
 
+            if "/" in name_token.value or os.sep in name_token.value:
+                part_splitter = ["/", os.sep]
+            else:
+                part_splitter = ["."]
+
+            reversed_text_before_position = list(reversed(text_before_position))
             last_separator_index = (
                 len(text_before_position)
-                - next((i for i, c in enumerate(reversed(text_before_position)) if c in [".", "/", os.sep]), -1)
+                - next(
+                    (
+                        i
+                        for i, c in enumerate(reversed_text_before_position)
+                        if c in part_splitter
+                        and (
+                            c != "\\"
+                            or (
+                                c == "\\"
+                                and len(reversed_text_before_position) > i + 1
+                                and reversed_text_before_position[i + 1] == "\\"
+                            )
+                        )
+                    ),
+                    -1,
+                )
                 - 1
             )
 
             first_part = (
                 text_before_position[
-                    : last_separator_index
-                    + (1 if text_before_position[last_separator_index] in [".", "/", os.sep] else 0)
+                    : last_separator_index + (1 if text_before_position[last_separator_index] in part_splitter else 0)
                 ]
                 if last_separator_index < len(text_before_position)
                 else None
@@ -1693,9 +1735,25 @@ class CompletionCollector(ModelHelperMixin):
         if text_before_position != "" and all(c == "." for c in text_before_position):
             return None
 
+        reversed_text_before_position = list(reversed(text_before_position))
         last_separator_index = (
             len(text_before_position)
-            - next((i for i, c in enumerate(reversed(text_before_position)) if c in ["/", os.sep]), -1)
+            - next(
+                (
+                    i
+                    for i, c in enumerate(reversed_text_before_position)
+                    if c in ["/", os.sep]
+                    and (
+                        c != "\\"
+                        or (
+                            c == "\\"
+                            and len(reversed_text_before_position) > i + 1
+                            and reversed_text_before_position[i + 1] == "\\"
+                        )
+                    )
+                ),
+                -1,
+            )
             - 1
         )
 
@@ -1795,9 +1853,30 @@ class CompletionCollector(ModelHelperMixin):
             if text_before_position != "" and all(c == "." for c in text_before_position):
                 return None
 
+            if "/" in name_token.value or os.sep in name_token.value:
+                part_splitter = ["/", os.sep]
+            else:
+                part_splitter = ["."]
+
+            reversed_text_before_position = list(reversed(text_before_position))
             last_separator_index = (
                 len(text_before_position)
-                - next((i for i, c in enumerate(reversed(text_before_position)) if c in ["/", os.sep]), -1)
+                - next(
+                    (
+                        i
+                        for i, c in enumerate(reversed_text_before_position)
+                        if c in part_splitter
+                        and (
+                            c != "\\"
+                            or (
+                                c == "\\"
+                                and len(reversed_text_before_position) > i + 1
+                                and reversed_text_before_position[i + 1] == "\\"
+                            )
+                        )
+                    ),
+                    -1,
+                )
                 - 1
             )
 
